@@ -1,5 +1,6 @@
-extern void send_file_dialog (void);
 extern gboolean
 obex_object_push (const gchar *filename, const gchar *mimetype, const gchar *data, size_t len,
 		  GCallback callback, gpointer cb_data);
 
+extern void
+obex_client_init (void);
